==> haskell-keys-3.12.3-254-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-keys.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 keys
version:              3.12.3
visibility:           public
id:                   keys-3.12.3-80PAZrZmpssJn8z11bM1SP
key:                  keys-3.12.3-80PAZrZmpssJn8z11bM1SP
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/keys/
synopsis:             Keyed functors and containers
description:
    This package provides a bunch of ad hoc classes for accessing parts of a container.

    In practice this package is largely subsumed by the
    <https://hackage.haskell.org/package/lens lens package>,
    but it is maintained for now as it has much
    simpler dependencies.

category:             Data Structures, Containers
abi:                  365a07f7f935d15bb9a744f1bcce9734
exposed:              True
exposed-modules:      Data.Key
import-dirs:          /usr/lib/ghc-9.0.2/site-local/keys-3.12.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/keys-3.12.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-keys
hs-libraries:         HSkeys-3.12.3-80PAZrZmpssJn8z11bM1SP
depends:
    array-0.5.4.0 base-4.15.1.0 comonad-5.0.8-EO5Hbt4D8A2DaWL40pc9ZN
    containers-0.6.4.1 free-5.1.10-5oMe3ysjXMxGRnsOFf8sMq
    hashable-1.4.2.0-DVbjlBr1LVBocftOjT6RF
    semigroupoids-5.3.7-J8YG1rXHNsfFOz0i03HsVi
    tagged-0.8.7-8MQxDldL1qw9fJF5LZxnpf transformers-0.5.6.2
    transformers-compat-0.7.2-ZzSHjvD4flB2ChCq5TVbH
    unordered-containers-0.2.19.1-LQtCnXuHNyW9sDB4jL9Yl3

haddock-interfaces:   /usr/share/doc/haskell-keys/html/keys.haddock
haddock-html:         /usr/share/doc/haskell-keys/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-keys-3.12.3-259-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-keys.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 keys
version:              3.12.3
visibility:           public
id:                   keys-3.12.3-45r94HuZxhwJxvP1TcgS8y
key:                  keys-3.12.3-45r94HuZxhwJxvP1TcgS8y
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/keys/
synopsis:             Keyed functors and containers
description:
    This package provides a bunch of ad hoc classes for accessing parts of a container.

    In practice this package is largely subsumed by the
    <https://hackage.haskell.org/package/lens lens package>,
    but it is maintained for now as it has much
    simpler dependencies.

category:             Data Structures, Containers
abi:                  c2c709bcefc789973cc9cea7112d61a6
exposed:              True
exposed-modules:      Data.Key
import-dirs:          /usr/lib/ghc-9.0.2/site-local/keys-3.12.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/keys-3.12.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-keys
hs-libraries:         HSkeys-3.12.3-45r94HuZxhwJxvP1TcgS8y
depends:
    array-0.5.4.0 base-4.15.1.0 comonad-5.0.8-79rjkBqJeE3GdCewGNIpd
    containers-0.6.4.1 free-5.1.10-8Qiso8m5FGQJVSV1xrbc1N
    hashable-1.4.2.0-DVbjlBr1LVBocftOjT6RF
    semigroupoids-5.3.7-Xhu880qc0CSSuormkKAs
    tagged-0.8.7-8MQxDldL1qw9fJF5LZxnpf transformers-0.5.6.2
    transformers-compat-0.7.2-ZzSHjvD4flB2ChCq5TVbH
    unordered-containers-0.2.19.1-1kxBI3XpAtt5E439x4IDIb

haddock-interfaces:   /usr/share/doc/haskell-keys/html/keys.haddock
haddock-html:         /usr/share/doc/haskell-keys/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
